markuptools.make_vertically_adjusted_composer_markup
====================================================

.. autofunction:: abjad.tools.markuptools.make_vertically_adjusted_composer_markup.make_vertically_adjusted_composer_markup
